@@ -75,6 +75,20 @@ eel_rectangle_contains (const GdkRectangle *rectangle,
 		&& rectangle->y <= y && rectangle->y + rectangle->height >= y;
 }
 
+/**
+ * eel_gdk_rectangle_contains_rectangle:
+ * @outer: Rectangle possibly containing another rectangle.
+ * @inner: Rectangle that might be inside.
+ *
+ * Retun TRUE if inner rectangle is contained inside outer rectangle
+ */
+gboolean
+eel_gdk_rectangle_contains_rectangle (GdkRectangle outer, GdkRectangle inner)
+{
+	return outer.x <= inner.x && outer.x + outer.width >= inner.x + inner.width
+		&& outer.y <= inner.y && outer.y + outer.height >= inner.y + inner.height;
+}
+
 /**
  * eel_rectangle_inset:
  * @rectangle: Rectangle we are insetting.
@@ -622,30 +636,6 @@ eel_gdk_window_set_wm_protocols (GdkWindow *window,
 	g_free (atoms);
 }
 
-void
-eel_set_mini_icon (GdkWindow *window,
-			GdkPixmap *pixmap,
-			GdkBitmap *mask)
-{
-        GdkAtom icon_atom;
-        long data[2];
- 
-        g_return_if_fail (window != NULL);
-        g_return_if_fail (pixmap != NULL);
-
-        data[0] = GDK_WINDOW_XWINDOW (pixmap);
-        if (mask) {
-                data[1] = GDK_WINDOW_XWINDOW (mask);
-        } else {
-                data[1] = 0;
-	}
-
-        icon_atom = gdk_atom_intern ("KWM_WIN_ICON", FALSE);
-        gdk_property_change (window, icon_atom, icon_atom, 
-                             32, GDK_PROP_MODE_REPLACE,
-                             (guchar *) data, 2);
-}
-
 /**
  * eel_gdk_window_set_wm_hints_input:
  * 
