@@ -28,7 +28,6 @@
 
 #include <gtk/gtkvbox.h>
 #include <eel/eel-preferences.h>
-#include <eel/eel-enumeration.h>
 
 G_BEGIN_DECLS
 
@@ -73,6 +72,7 @@ typedef enum
 	EEL_PREFERENCE_ITEM_BOOLEAN,
 	EEL_PREFERENCE_ITEM_CUSTOM,
 	EEL_PREFERENCE_ITEM_EDITABLE_INTEGER,
+	EEL_PREFERENCE_ITEM_EDITABLE_PASSWORD_STRING,
 	EEL_PREFERENCE_ITEM_EDITABLE_STRING,
 	EEL_PREFERENCE_ITEM_ENUMERATION_HORIZONTAL_RADIO,
 	EEL_PREFERENCE_ITEM_ENUMERATION_LIST_HORIZONTAL,
@@ -81,7 +81,6 @@ typedef enum
 	EEL_PREFERENCE_ITEM_ENUMERATION_VERTICAL_RADIO,
 	EEL_PREFERENCE_ITEM_FONT,
 	EEL_PREFERENCE_ITEM_PADDING,
-	EEL_PREFERENCE_ITEM_SMOOTH_FONT
 } EelPreferencesItemType;
 
 typedef enum
