@@ -32,7 +32,6 @@
 #include "eel-types.h"
 #include <gtk/gtkmain.h>
 #include <gtk/gtkviewport.h>
-#include <libgnome/gnome-i18n.h>
 
 /* Arguments */
 enum
@@ -137,31 +136,19 @@ eel_wrap_table_class_init (EelWrapTableClass *wrap_table_class)
 	g_object_class_install_property
 		(gobject_class,
 		 PROP_X_SPACING,
-		 g_param_spec_uint ("x_spacing",
-				    _("horizontal spacing"),
-				    _("The amount of horizontal spacing."),
-				    0,
-				    G_MAXINT,
-				    0,
-				    G_PARAM_READWRITE));
+		 g_param_spec_uint ("x_spacing", NULL, NULL,
+                                    0, G_MAXINT, 0, G_PARAM_READWRITE));
 
 	g_object_class_install_property
 		(gobject_class,
 		 PROP_Y_SPACING,
-		 g_param_spec_uint ("y_spacing",
-				    _("vertical spacing"),
-				    _("The amount of vertical spacing."),
-				    0,
-				    G_MAXINT,
-				    0,
-				    G_PARAM_READWRITE));
+		 g_param_spec_uint ("y_spacing", NULL, NULL,
+				    0, G_MAXINT, 0, G_PARAM_READWRITE));
 	
 	g_object_class_install_property
 		(gobject_class,
 		 PROP_X_JUSTIFICATION,
-		 g_param_spec_enum ("x_justification",
-				    _("horizontal justification"),
-				    _("Left, right, or center justification"),
+		 g_param_spec_enum ("x_justification", NULL, NULL,
 				    EEL_TYPE_JUSTIFICATION,
 				    EEL_JUSTIFICATION_BEGINNING,
 				    G_PARAM_READWRITE));
@@ -169,9 +156,7 @@ eel_wrap_table_class_init (EelWrapTableClass *wrap_table_class)
 	g_object_class_install_property
 		(gobject_class,
 		 PROP_Y_JUSTIFICATION,
-		 g_param_spec_enum ("y_justification",
-				    _("vertical justification"),
-				    _("Top, bottom, or middle justification"),
+		 g_param_spec_enum ("y_justification", NULL, NULL,
 				    EEL_TYPE_JUSTIFICATION,
 				    EEL_JUSTIFICATION_BEGINNING,
 				    G_PARAM_READWRITE));
@@ -179,11 +164,8 @@ eel_wrap_table_class_init (EelWrapTableClass *wrap_table_class)
 	g_object_class_install_property
 		(gobject_class,
 		 PROP_HOMOGENEOUS,
-		 g_param_spec_boolean ("homogenous",
-				       _("homogenous"),
-				       _("homogeneous layout"),
-				       FALSE,
-				       G_PARAM_READWRITE));
+		 g_param_spec_boolean ("homogenous", NULL, NULL,
+				       FALSE, G_PARAM_READWRITE));
 }
 
 void
